@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2013 Glenn Randers-Pehrson
  * Written by Mans Rullgard, 2011.
- * Last changed in libpng 1.6.5 [September 14, 2013]
+ * Last changed in libpng 1.6.5 [September 16, 2013]
  *
  * This code is released under the libpng license.
  * For conditions of distribution and use, see the disclaimer
@@ -17,8 +17,6 @@
 #include "../pngpriv.h"
 
 #ifdef PNG_READ_SUPPORTED
-  if (((png_ptr->options >> PNG_MAXIMUM_INFLATE_WINDOW) & 3) ==
-     PNG_OPTION_ON)
 #if PNG_ARM_NEON_OPT > 0
 #ifdef PNG_ARM_NEON_CHECK_SUPPORTED /* Do run-time checks */
 #include <signal.h> /* for sig_atomic_t */
